==> qmmp-plugin-pack-0.6.0.tar.bz2: qmmp-plugin-pack-0.6.0/src/Input/ffap/translations/ffap_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="48"/>
        <source>FFap Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="50"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>About FFap Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="155"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="156"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="157"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="60"/>
        <source>Length</source>
        <translation type="unfinished">Тривалість</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Sample rate</source>
        <translation type="unfinished">Частота</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Hz</source>
        <translation type="unfinished">Гц</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Channels</source>
        <translation type="unfinished">Канали</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Bitrate</source>
        <translation type="unfinished">Бітрейт</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>kbps</source>
        <translation type="unfinished">Кб/с</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>File size</source>
        <translation type="unfinished">Розмір файлу</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>KB</source>
        <translation type="unfinished">Кб</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-0.8.6.tar.bz2: qmmp-plugin-pack-0.8.6/src/Input/ffap/translations/ffap_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="48"/>
        <source>FFap Plugin</source>
        <translation>Модуль FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="50"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Файли Monkey&apos;s Audio</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>About FFap Audio Plugin</source>
        <translation>Про аудіо-модуль FFap для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Аудіо-модуль FFap для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="155"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Цей модуль додає підтримку Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="156"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="157"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Засновано на вихідному коді проектів deadbeef, FFmpeg та rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="60"/>
        <source>Length</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Sample rate</source>
        <translation>Частота</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Channels</source>
        <translation>Канали</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Bitrate</source>
        <translation>Бітрейт</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>File size</source>
        <translation>Розмір файлу</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>KB</source>
        <translation>Кб</translation>
    </message>
</context>
</TS>
